==> nextcloud-20.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/sl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna plošča",
    "Dashboard app" : "Program Nadzorna plošča",
    "Show something" : "Pokaži karkoli",
    "Customize" : "Prilagodi",
    "Edit widgets" : "Izbor gradnikov",
    "Get more widgets from the app store" : "Pridobi več gradnikov iz zbirke",
    "Change background image" : "Izbor slike ozadja",
    "Weather service" : "Vremenske storitve",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Za večjo zasebnost so podatki vremena pridobljeni prek strežnika Nextcloud, zato tretje osebe ne pridobijo nobenega vašega osebnega podatka.",
    "Weather data from Met.no" : "Podatke vremena omogoča Met.no",
    "geocoding with Nominatim" : "geokodiranje Nominatim",
    "elevation data from OpenTopoData" : "podatke nadmorske višine OpenTopoData",
    "Weather" : "Vreme",
    "Status" : "Stanje",
    "Good evening, {name}" : "Dober večer, {name}",
    "Good evening" : "Dober večer",
    "Good afternoon, {name}" : "Dober dan, {name}",
    "Good afternoon" : "Dober dan",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good morning" : "Dobro jutro",
    "Good night, {name}" : "Lahko noč, {name}",
    "Good night" : "Lahko noč",
    "Pick from files" : "Izbor iz datotek",
    "Default images" : "Privzete slike",
    "Plain background" : "Enostavno ozadje",
    "Insert from {productName}" : "Vstavi iz {productName}"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/sl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Nadzorna plošča",
    "Dashboard app" : "Program Nadzorna plošča",
    "Show something" : "Pokaži karkoli",
    "Customize" : "Prilagodi",
    "Edit widgets" : "Izbor gradnikov",
    "Get more widgets from the app store" : "Pridobi več gradnikov iz zbirke",
    "Change background image" : "Izbor slike ozadja",
    "Weather service" : "Vremenske storitve",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Za večjo zasebnost so podatki vremena pridobljeni prek strežnika Nextcloud, zato tretje osebe ne pridobijo nobenega vašega osebnega podatka.",
    "Weather data from Met.no" : "Podatke vremena omogoča Met.no",
    "geocoding with Nominatim" : "geokodiranje Nominatim",
    "elevation data from OpenTopoData" : "podatke nadmorske višine OpenTopoData",
    "Weather" : "Vreme",
    "Status" : "Stanje",
    "Good morning" : "Dobro jutro",
    "Good morning, {name}" : "Dobro jutro, {name}",
    "Good afternoon" : "Dober dan",
    "Good afternoon, {name}" : "Dober dan, {name}",
    "Good evening" : "Dober večer",
    "Good evening, {name}" : "Dober večer, {name}",
    "Default images" : "Privzete slike",
    "Plain background" : "Enostavno ozadje",
    "Insert from {productName}" : "Vstavi iz {productName}",
    "Good night, {name}" : "Lahko noč, {name}",
    "Good night" : "Lahko noč",
    "Pick from files" : "Izbor iz datotek"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
